#!/bin/bash
# Licensed Materials - Property of IBM
# 5724-I68
#
# (C) Copyright IBM Corp. 2000, 2006
#
# US Government Users Restricted Rights - Use, duplication, or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.


. ${TOP}/bin/get_params.sh

printUsage()
{
	${ECHO} "USAGE: "$0" --code=<Company code> --category=<category pk>"
 	${ECHO} "EXAMPLE: "$0" --code=ibm --category=\"Basic Category\""
 	exit 0
}

if [ $# -lt 2 ]
then
	printUsage
fi

. ${TOP}/src/db/schema/util/set_db.sh
_ERROR_LOGS=$TOP/logs/delete_ca_category.log
tmpfile=$TOP/logs/del_category_temp.out
tmpsqlfile=$TOP/logs/del_category_temp.sql
date > $_ERROR_LOGS

if [ "${_CCD_CODE}" = "" ]; then
    printUsage
    exit
fi

${TOUCH} tmpcmpid.sql
${CAT} $DB_SCRIPTS/get_cmpid_for_cmpcode.sql | ${SED} "s/%_CCD_CODE%/$_CCD_CODE/g" > tmpcmpid.sql
CMP_ID=`. ${TOP}/src/db/schema/util/run_db_cmd.sh --file=tmpcmpid.sql --errorfilter=yes | ${GREP} 'cmpid-'| cut -f2 -d "-"`

if [ "$CMP_ID" != "" ]; then
  ${ECHO} "COMPANY ID = " $CMP_ID >> $_ERROR_LOGS
  ${RM} tmpcmpid.sql
else 
  ${ECHO} "Company code not found"
  ${ECHO} $_CCD_CODE
  exit 0
fi

cleanup_exit()
{
${RM} $tmpfile
${RM} $tmpsqlfile
exit
}

${ECHO} "select 'catid= ', cat_id from cat where cat_primary_key = '$_CCD_CATEGORY' and cat_company_id = $CMP_ID and cat_next_version_id = 999999999 and cat_container_id in (select ctr_id from ctr where ctr_type = 'CATEGORY_TREE');" > $tmpsqlfile
CAT_ID=`. ${TOP}/src/db/schema/util/run_db_cmd.sh --file=$tmpsqlfile --errorfilter=yes| ${GREP} 'catid='| cut -f2 -d "="`

if [ "$CAT_ID" != "" ]; then
  ${ECHO} "CAT ID = " $CAT_ID >> $_ERROR_LOGS
else 
  ${ECHO} "Category not found"
  ${ECHO} $_CCD_CATEGORY
  cleanup_exit
fi

${ECHO} "select 'catid= ', cat_id from cat where cat_primary_key = '$_CCD_CATEGORY' and cat_company_id = $CMP_ID and cat_next_version_id = 999999999 and cat_container_id in (select ctr_id from ctr where ctr_type = 'COLLABORATION_AREA');" > $tmpsqlfile
CA_CAT_ID=`. ${TOP}/src/db/schema/util/run_db_cmd.sh --file=$tmpsqlfile --errorfilter=yes| ${GREP} 'catid='| cut -f2 -d "="`

if [ "$CA_CAT_ID" != "" ]; then
  ${ECHO} "CA CAT ID = " $CA_CAT_ID >> $_ERROR_LOGS
else 
  ${ECHO} "Category " $_CCD_CATEGORY " is not in collab area"
  ${ECHO} "Updating source category..."
  CA_CAT_ID=0
fi

cat << EOF > $tmpsqlfile
DELETE FROM CEL WHERE CEL_ENTRY_ID IN (SELECT CEM_CA_ENTRY_ID FROM CEM WHERE CEM_SRC_ENTRY_ID = $CA_CAT_ID);
DELETE FROM CAE WHERE CAE_ENTRY_ID IN (SELECT CEM_CA_ENTRY_ID FROM CEM WHERE CEM_SRC_ENTRY_ID = $CA_CAT_ID);
DELETE FROM CEM WHERE CEM_SRC_ENTRY_ID = $CA_CAT_ID;
DELETE FROM SCA WHERE SCA_CATEGORY_ID= $CA_CAT_ID AND SCA_COMPANY_ID = $CMP_ID AND SCA_CAT_TREE_ID IN (SELECT CTR_ID FROM CTR WHERE CTR_TYPE = 'COLLABORATION_AREA');
DELETE FROM ULE WHERE ULE_CATEGORY_ID= $CA_CAT_ID AND ULE_CONTAINER_ID IN (SELECT CTR_ID FROM CTR WHERE CTR_TYPE = 'COLLABORATION_AREA');
DELETE FROM COM WHERE COM_CATEGORY_ID= $CA_CAT_ID AND COM_COMPANY_ID = $CMP_ID AND COM_CATEGORY_TREE_ID IN (SELECT CTR_ID FROM CTR WHERE CTR_TYPE = 'COLLABORATION_AREA');
DELETE FROM CMC WHERE CMC_CATEGORY_ID= $CA_CAT_ID AND CMC_COMPANY_ID = $CMP_ID;
DELETE FROM CSA WHERE CSA_CATEGORY_ID= $CA_CAT_ID AND CSA_COMPANY_ID = $CMP_ID AND CSA_NEXT_VERSION_ID = 999999999 AND CSA_CAT_TREE_ID IN (SELECT CTR_ID FROM CTR WHERE CTR_TYPE = 'COLLABORATION_AREA');
DELETE FROM CSM WHERE CSM_CATEGORY_ID= $CA_CAT_ID AND CSM_COMPANY_ID = $CMP_ID AND CSM_NEXT_VERSION_ID = 999999999 AND CSM_CAT_TREE_ID IN (SELECT CTR_ID FROM CTR WHERE CTR_TYPE = 'COLLABORATION_AREA');
DELETE FROM CCM WHERE CCM_SRC_CATEGORY_ID= $CA_CAT_ID AND CCM_COMPANY_ID = $CMP_ID AND CCM_NEXT_VERSION_ID = 999999999 AND CCM_SRC_CAT_TREE_ID IN (SELECT CTR_ID FROM CTR WHERE CTR_TYPE = 'COLLABORATION_AREA');
DELETE FROM CCM WHERE CCM_DST_CATEGORY_ID= $CA_CAT_ID AND CCM_COMPANY_ID = $CMP_ID AND CCM_NEXT_VERSION_ID = 999999999 AND CCM_DST_CAT_TREE_ID IN (SELECT CTR_ID FROM CTR WHERE CTR_TYPE = 'COLLABORATION_AREA');
DELETE FROM CAB WHERE CAB_CATEGORY_ID= $CA_CAT_ID AND CAB_COMPANY_ID = $CMP_ID AND CAB_NEXT_VERSION_ID = 999999999 AND CAB_CAT_TREE_ID IN (SELECT CTR_ID FROM CTR WHERE CTR_TYPE = 'COLLABORATION_AREA');
DELETE FROM CAD WHERE CAD_CATEGORY_ID= $CA_CAT_ID AND CAD_COMPANY_ID = $CMP_ID AND CAD_NEXT_VERSION_ID = 999999999 AND CAD_CONTAINER_ID IN (SELECT CTR_ID FROM CTR WHERE CTR_TYPE = 'COLLABORATION_AREA');
DELETE FROM CFP WHERE CFP_CATEGORY_ID= $CA_CAT_ID AND CFP_COMPANY_ID = $CMP_ID AND CFP_NEXT_VERSION_ID = 999999999 AND CFP_CAT_TREE_ID IN (SELECT CTR_ID FROM CTR WHERE CTR_TYPE = 'COLLABORATION_AREA');
DELETE FROM CAT WHERE CAT_ID = $CA_CAT_ID AND CAT_COMPANY_ID = $CMP_ID AND CAT_NEXT_VERSION_ID = 999999999 AND CAT_CONTAINER_ID IN (SELECT CTR_ID FROM CTR WHERE CTR_TYPE = 'COLLABORATION_AREA');
DELETE FROM ICM WHERE ICM_CATEGORY_ID= $CA_CAT_ID AND ICM_COMPANY_ID = $CMP_ID AND ICM_NEXT_VERSION_ID = 999999999 AND ICM_CAT_TREE_ID IN (SELECT CTR_ID FROM CTR WHERE CTR_TYPE = 'COLLABORATION_AREA');
UPDATE CAT SET CAT_COLLAB_INFO = NULL WHERE CAT_ID = $CAT_ID AND CAT_NEXT_VERSION_ID = 999999999 AND CAT_CONTAINER_ID IN
(SELECT CTR_ID FROM CTR WHERE CTR_TYPE = 'CATEGORY_TREE');
EOF

. ${TOP}/src/db/schema/util/run_db_cmd.sh --file=$tmpsqlfile >> $_ERROR_LOGS
${ECHO} "Delete collab category completed" 
${ECHO} "Check error logs for status : " $_ERROR_LOGS

cleanup_exit

